
%global goroot /usr/lib/golang
%global gopath /gocode

# This if for the .go files
%global sdk_src_path /src/github.com/oracle/oci-go-sdk

# This is used to create the configuration files
# The default value for the RPM builtin _datadir macro is /usr/share
# This can be changed in the .rpmmacros file
%global preferred_3rdparty_gopath %{_datadir}

# No need to have a debuginfo rpm for this package
%define debug_package %{nil}

# Note that the name of the RPM (go-oci-sdk) is switched
# wrt the name of the package on github (oci-go-sdk)
%define sdkname oci-go-sdk

Name:           go-oci-sdk
Version:        65.31.1
Release:        1%{?dist}
Summary:        Go SDK for Oracle Cloud Infrastructure
Group:          Development/go
BuildArch:      noarch

License:        UPL
URL:            https://godoc.org/github.com/oracle/oci-go-sdk
Source0:        %{sdkname}-%{version}.zip

Requires: golang
Requires: gobreaker
Requires: flock

# Two files are generated which contain commands to set
# the GOPATH env variable correctly for the oci-go-sdk users
# There are two flavors, one for bash and one for C shell
%define config_sh_script %{name}-config.sh
%define config_csh_script %{name}-config.csh
%define config_script_dir /etc/profile.d

%description
This is the official Go SDK for Oracle Cloud Infrastructure

%prep
# The zip file from github unpacks as oci-go-sdk, (w/o the version number)
%setup -q -n %{sdkname}

# Generate the sh version of the script to set up the GOPATH env variable
cat > %{config_sh_script} <<EOF
#!/bin/bash
# This file is intended to set GOPATH for go-oci-sdk
# Make sure you run this script with "source" instead of "sh"
# otherwise the setting of the environment variable will not take place
if [ -z "\${GOPATH}" ] ; then
  export GOPATH="%{preferred_3rdparty_gopath}%{gopath}"
else
  export GOPATH="\$GOPATH:%{preferred_3rdparty_gopath}%{gopath}"
fi
EOF

# Generate the tcsh version of the script to set up the GOPATH env variable
cat > %{config_csh_script} <<EOF
#!/bin/tcsh
# This file is intended to set GOPATH for go-oci-sdk
# Make sure you run this script with "source" instead of "tcsh"
# otherwise the setting of the environment variable will not take place
if ( ! \$?GOPATH ) then
  setenv GOPATH ""
endif

if ( "\$GOPATH" == "" ) then
  setenv GOPATH %{preferred_3rdparty_gopath}%{gopath}
else
  setenv GOPATH \$GOPATH\:%{preferred_3rdparty_gopath}%{gopath}
endif
EOF

%build

# Nothing to do here, we just need to install the files
# packaged in the zip file, they do not need to be built

%install

# Create /etc/profile.d under the buildroot to store the
# shell configuration scripts
mkdir -p $RPM_BUILD_ROOT%{config_script_dir}

# Install the two configuration scripts
install -m 644 %{config_sh_script} $RPM_BUILD_ROOT%{config_script_dir}
install -m 644 %{config_csh_script} $RPM_BUILD_ROOT%{config_script_dir}

# Remove them from the BUILD directory
rm -f %{config_sh_script}
rm -f %{config_csh_script}


# Create /usr/share/gocode/src/github.com/oracle/oci-go-sdk under
# the buildroot to store the sdk files
install -d %{buildroot}%{preferred_3rdparty_gopath}%{gopath}%{sdk_src_path}


cp -r %{_builddir}/%{sdkname}/* %{buildroot}%{preferred_3rdparty_gopath}%{gopath}%{sdk_src_path}/
chmod 755 %{buildroot}%{preferred_3rdparty_gopath}%{gopath}%{sdk_src_path}/

%files
%doc
%{preferred_3rdparty_gopath}%{gopath}%{sdk_src_path}/*
%{config_script_dir}/%{config_sh_script}
%{config_script_dir}/%{config_csh_script}


%changelog
* Tue Feb 28 2023 El Errata <el-errata_ww@oracle.com> - 65.31.1-1
- Import version 65.31.1

* Tue Feb 21 2023 El Errata <el-errata_ww@oracle.com> - 65.31.0-1
- Import version 65.31.0

* Tue Feb 14 2023 El Errata <el-errata_ww@oracle.com> - 65.30.0-1
- Import version 65.30.0

* Tue Feb 07 2023 El Errata <el-errata_ww@oracle.com> - 65.29.0-1
- Import version 65.29.0

* Tue Jan 31 2023 El Errata <el-errata_ww@oracle.com> - 65.28.3-1
- Import version 65.28.3

* Tue Jan 24 2023 El Errata <el-errata_ww@oracle.com> - 65.28.2-1
- Import version 65.28.2

* Tue Jan 17 2023 El Errata <el-errata_ww@oracle.com> - 65.28.1-1
- Import version 65.28.1

* Tue Dec 13 2022 El Errata <el-errata_ww@oracle.com> - 65.28.0-1
- Import version 65.28.0

* Tue Dec 06 2022 El Errata <el-errata_ww@oracle.com> - 65.27.0-1
- Import version 65.27.0

* Tue Nov 15 2022 El Errata <el-errata_ww@oracle.com> - 65.26.1-1
- Import version 65.26.1

* Tue Nov 08 2022 El Errata <el-errata_ww@oracle.com> - 65.26.0-1
- Import version 65.26.0

* Tue Nov 01 2022 El Errata <el-errata_ww@oracle.com> - 65.25.0-1
- Import version 65.25.0

* Tue Oct 25 2022 El Errata <el-errata_ww@oracle.com> - 65.24.0-1
- Import version 65.24.0

* Tue Oct 04 2022 El Errata <el-errata_ww@oracle.com> - 65.23.0-1
- Import version 65.23.0

* Tue Sep 27 2022 El Errata <el-errata_ww@oracle.com> - 65.22.0-1
- Import version 65.22.0

* Tue Sep 20 2022 El Errata <el-errata_ww@oracle.com> - 65.21.0-1
- Import version 65.21.0

* Tue Sep 13 2022 El Errata <el-errata_ww@oracle.com> - 65.20.0-1
- Import version 65.20.0

* Tue Sep 06 2022 El Errata <el-errata_ww@oracle.com> - 65.19.0-1
- Import version 65.19.0

* Tue Aug 30 2022 El Errata <el-errata_ww@oracle.com> - 65.18.1-1
- Import version 65.18.1

* Tue Aug 23 2022 El Errata <el-errata_ww@oracle.com> - 65.18.0-1
- Import version 65.18.0

* Tue Aug 16 2022 El Errata <el-errata_ww@oracle.com> - 65.17.0-1
- Import version 65.17.0

* Tue Aug 09 2022 El Errata <el-errata_ww@oracle.com> - 65.16.0-1
- Import version 65.16.0

* Tue Aug 02 2022 El Errata <el-errata_ww@oracle.com> - 65.15.0-1
- Import version 65.15.0

* Tue Jul 26 2022 El Errata <el-errata_ww@oracle.com> - 65.14.0-1
- Import version 65.14.0

* Tue Jul 19 2022 El Errata <el-errata_ww@oracle.com> - 65.13.1-1
- Import version 65.13.1

* Tue Jul 12 2022 El Errata <el-errata_ww@oracle.com> - 65.13.0-1
- Import version 65.13.0

* Tue Jul 05 2022 El Errata <el-errata_ww@oracle.com> - 65.12.0-1
- Import version 65.12.0

* Tue Jun 28 2022 El Errata <el-errata_ww@oracle.com> - 65.11.0-1
- Import version 65.11.0

* Tue Jun 21 2022 El Errata <el-errata_ww@oracle.com> - 65.10.0-1
- Import version 65.10.0

* Tue Jun 14 2022 El Errata <el-errata_ww@oracle.com> - 65.9.0-1
- Import version 65.9.0

* Tue Jun 07 2022 El Errata <el-errata_ww@oracle.com> - 65.8.1-1
- Import version 65.8.1

* Tue May 31 2022 El Errata <el-errata_ww@oracle.com> - 65.8.0-1
- Import version 65.8.0

* Tue May 24 2022 El Errata <el-errata_ww@oracle.com> - 65.7.0-1
- Import version 65.7.0

* Tue May 17 2022 El Errata <el-errata_ww@oracle.com> - 65.6.0-1
- Import version 65.6.0

* Tue May 10 2022 El Errata <el-errata_ww@oracle.com> - 65.5.0-1
- Import version 65.5.0

* Tue May 03 2022 El Errata <el-errata_ww@oracle.com> - 65.4.0-1
- Import version 65.4.0

* Tue Apr 26 2022 El Errata <el-errata_ww@oracle.com> - 65.3.0-1
- Import version 65.3.0

* Tue Apr 19 2022 El Errata <el-errata_ww@oracle.com> - 65.2.0-1
- Import version 65.2.0

* Tue Apr 12 2022 El Errata <el-errata_ww@oracle.com> - 65.1.0-1
- Import version 65.1.0

* Tue Apr 05 2022 El Errata <el-errata_ww@oracle.com> - 65.0.0-1
- Import version 65.0.0

* Tue Mar 29 2022 El Errata <el-errata_ww@oracle.com> - 64.0.0-1
- Import version 64.0.0

* Tue Mar 22 2022 El Errata <el-errata_ww@oracle.com> - 63.0.0-1
- Import version 63.0.0

* Tue Mar 15 2022 El Errata <el-errata_ww@oracle.com> - 62.0.0-1
- Import version 62.0.0

* Tue Mar 08 2022 El Errata <el-errata_ww@oracle.com> - 61.0.0-1
- Import version 61.0.0

* Tue Mar 01 2022 El Errata <el-errata_ww@oracle.com> - 60.0.0-1
- Import version 60.0.0

* Tue Feb 22 2022 El Errata <el-errata_ww@oracle.com> - 59.0.0-1
- Import version 59.0.0

* Tue Feb 15 2022 El Errata <el-errata_ww@oracle.com> - 58.0.0-1
- Import version 58.0.0

* Tue Feb 08 2022 El Errata <el-errata_ww@oracle.com> - 57.0.0-1
- Import version 57.0.0

* Tue Feb 01 2022 El Errata <el-errata_ww@oracle.com> - 56.1.0-1
- Import version 56.1.0

* Tue Jan 25 2022 El Errata <el-errata_ww@oracle.com> - 56.0.0-1
- Import version 56.0.0

* Tue Jan 18 2022 El Errata <el-errata_ww@oracle.com> - 55.1.0-1
- Import version 55.1.0

* Tue Jan 11 2022 El Errata <el-errata_ww@oracle.com> - 55.0.0-1
- Import version 55.0.0

* Tue Dec 14 2021 El Errata <el-errata_ww@oracle.com> - 54.0.0-1
- Import version 54.0.0

* Tue Dec 07 2021 El Errata <el-errata_ww@oracle.com> - 53.1.0-1
- Import version 53.1.0

* Tue Nov 30 2021 El Errata <el-errata_ww@oracle.com> - 53.0.0-1
- Import version 53.0.0

* Wed Nov 17 2021 El Errata <el-errata_ww@oracle.com> - 52.0.0-1
- Import version 52.0.0

* Tue Nov 09 2021 El Errata <el-errata_ww@oracle.com> - 51.0.0-1
- Import version 51.0.0

* Tue Nov 02 2021 El Errata <el-errata_ww@oracle.com> - 50.1.0-1
- Import version 50.1.0

* Tue Oct 26 2021 El Errata <el-errata_ww@oracle.com> - 50.0.0-1
- Import version 50.0.0

* Tue Oct 19 2021 El Errata <el-errata_ww@oracle.com> - 49.2.0-1
- Import version 49.2.0

* Tue Oct 12 2021 El Errata <el-errata_ww@oracle.com> - 49.1.0-1
- Import version 49.1.0

* Tue Oct 05 2021 El Errata <el-errata_ww@oracle.com> - 49.0.0-1
- Import version 49.0.0

* Tue Sep 28 2021 El Errata <el-errata_ww@oracle.com> - 48.0.0-1
- Import version 48.0.0

* Tue Sep 14 2021 El Errata <el-errata_ww@oracle.com> - 47.1.0-1
- Import version 47.1.0

* Tue Sep 07 2021 El Errata <el-errata_ww@oracle.com> - 47.0.0-1
- Import version 47.0.0

* Tue Aug 31 2021 El Errata <el-errata_ww@oracle.com> - 46.2.0-1
- Import version 46.2.0

* Tue Aug 24 2021 El Errata <el-errata_ww@oracle.com> - 46.1.0-1
- Import version 46.1.0

* Tue Aug 17 2021 El Errata <el-errata_ww@oracle.com> - 46.0.0-1
- Import version 46.0.0

* Tue Aug 03 2021 El Errata <el-errata_ww@oracle.com> - 45.2.0-1
- Import version 45.2.0

* Tue Jul 27 2021 El Errata <el-errata_ww@oracle.com> - 45.1.0-1
- Import version 45.1.0

* Tue Jul 20 2021 El Errata <el-errata_ww@oracle.com> - 45.0.0-1
- Import version 45.0.0

* Tue Jul 13 2021 El Errata <el-errata_ww@oracle.com> - 44.0.0-1
- Import version 44.0.0

* Tue Jul 06 2021 El Errata <el-errata_ww@oracle.com> - 43.1.0-1
- Import version 43.1.0

* Tue Jun 29 2021 El Errata <el-errata_ww@oracle.com> - 43.0.0-1
- Import version 43.0.0

* Tue Jun 22 2021 El Errata <el-errata_ww@oracle.com> - 42.1.0-1
- Import version 42.1.0

* Tue Jun 15 2021 El Errata <el-errata_ww@oracle.com> - 42.0.0-1
- Import version 42.0.0

* Tue Jun 08 2021 El Errata <el-errata_ww@oracle.com> - 41.2.0-1
- Import version 41.2.0

* Tue Jun 01 2021 El Errata <el-errata_ww@oracle.com> - 41.1.0-1
- Import version 41.1.0

* Tue May 25 2021 El Errata <el-errata_ww@oracle.com> - 41.0.0-1
- Import version 41.0.0

* Tue May 18 2021 El Errata <el-errata_ww@oracle.com> - 40.4.0-1
- Import version 40.4.0

* Tue May 11 2021 El Errata <el-errata_ww@oracle.com> - 40.3.0-1
- Import version 40.3.0

* Tue May 04 2021 El Errata <el-errata_ww@oracle.com> - 40.2.0-1
- Import version 40.2.0

* Tue Apr 27 2021 El Errata <el-errata_ww@oracle.com> - 40.1.0-1
- Import version 40.1.0

* Tue Apr 20 2021 El Errata <el-errata_ww@oracle.com> - 40.0.0-1
- Import version 40.0.0

* Tue Apr 13 2021 El Errata <el-errata_ww@oracle.com> - 39.0.0-1
- Import version 39.0.0

* Tue Apr 06 2021 El Errata <el-errata_ww@oracle.com> - 38.1.0-1
- Import version 38.1.0

* Tue Mar 30 2021 El Errata <el-errata_ww@oracle.com> - 38.0.0-1
- Import version 38.0.0

* Tue Mar 23 2021 El Errata <el-errata_ww@oracle.com> - 37.0.0-1
- Import version 37.0.0

* Tue Mar 16 2021 El Errata <el-errata_ww@oracle.com> - 36.2.0-1
- Import version 36.2.0

* Tue Mar 09 2021 El Errata <el-errata_ww@oracle.com> - 36.1.0-1
- Import version 36.1.0

* Tue Mar 02 2021 El Errata <el-errata_ww@oracle.com> - 36.0.0-1
- Import version 36.0.0

* Tue Feb 23 2021 El Errata <el-errata_ww@oracle.com> - 35.3.0-1
- Import version 35.3.0

* Tue Feb 16 2021 El Errata <el-errata_ww@oracle.com> - 35.2.0-1
- Import version 35.2.0

* Tue Feb 09 2021 El Errata <el-errata_ww@oracle.com> - 35.1.0-1
- Import version 35.1.0

* Tue Feb 02 2021 El Errata <el-errata_ww@oracle.com> - 35.0.0-1
- Import version 35.0.0

* Tue Jan 26 2021 El Errata <el-errata_ww@oracle.com> - 34.0.0-1
- Import version 34.0.0

* Tue Jan 19 2021 El Errata <el-errata_ww@oracle.com> - 33.0.0-1
- Import version 33.0.0

* Tue Jan 12 2021 El Errata <el-errata_ww@oracle.com> - 32.0.0-1
- Import version 32.0.0

* Tue Dec 15 2020 El Errata <el-errata_ww@oracle.com> - 31.0.0-1
- Import version 31.0.0

* Tue Dec 08 2020 El Errata <el-errata_ww@oracle.com> - 30.1.0-1
- Import version 30.1.0

* Tue Dec 01 2020 El Errata <el-errata_ww@oracle.com> - 30.0.0-1
- Import version 30.0.0

* Tue Nov 17 2020 El Errata <el-errata_ww@oracle.com> - 29.0.0-1
- Import version 29.0.0

* Tue Nov 10 2020 El Errata <el-errata_ww@oracle.com> - 28.0.0-1
- Import version 28.0.0

* Tue Nov 03 2020 El Errata <el-errata_ww@oracle.com> - 27.3.0-1
- Import version 27.3.0

* Tue Oct 27 2020 El Errata <el-errata_ww@oracle.com> - 27.2.0-1
- Import version 27.2.0

* Tue Oct 20 2020 El Errata <el-errata_ww@oracle.com> - 27.1.0-1
- Import version 27.1.0

* Tue Oct 13 2020 El Errata <el-errata_ww@oracle.com> - 27.0.0-1
- Import version 27.0.0

* Wed Sep 23 2020 Elena Zannoni <elena.zannoni@oracle.com> - 25.1.0-1
- Import version 25.1.0

* Thu Jul 23 2020 Elena Zannoni <elena.zannoni@oracle.com> - 21.3.0-1
- Import version 21.3.0
- Remove workaround for executable file in example directory
- Add Group

* Wed Jun 17 2020 Elena Zannoni <elena.zannoni@oracle.com> - 20.0.0-3
- Fix the two scripts to actually do the right thing
- Bump version to -3

* Wed Jun 17 2020 Elena Zannoni <elena.zannoni@oracle.com> - 20.0.0-2
- Add Requires golang

* Mon Jun 15 2020 Elena Zannoni <elena.zannoni@oracle.com> - 20.0.0-1
- Import new 20.0.0 release
- Orabug: 31492865
- Work around wrong permissions for one file in the upstreaam distro
- Major cleanup and semplilfication of the spec file

* Fri May 24 2019 Stephen Kyoungwon Kim <stephen.kim@oracle.com> - 5.10.0-2
- Move the package to /usr/share/gocode, which seems a preferred location for 3rd party packages

* Fri May 24 2019 Stephen Kyoungwon Kim <stephen.kim@oracle.com> - 5.10.0-1
- Import 5.10.0

* Fri May 24 2019 Stephen Kyoungwon Kim <stephen.kim@oracle.com> - 5.4.0-3
- Include /usr/lib/golang/src/github.com/oracle/oci-go-sdk directory in the package
- Oracle-Bug: 29909474

* Fri May 24 2019 Stephen Kyoungwon Kim <stephen.kim@oracle.com> - 5.4.0-2
- updated to keep Lans' changes made in 4.0.0-3

* Fri May 24 2019 Tianyue Lan <tianyue.lan@oracle.com> - 5.4.0-1
- import v5.4.0 as of May 21 2019
- Stephen <stephen.kim@oracle.com> cherry-picked from Tianyue's original commit

* Tue May 21 2019 Lans Hung <lans.hung@oracle.com> 4.0.0-3
- Fix spec file to build for specific version only.
- Change install location to /usr/lib instead of /usr/lib64
- Fix error when downloading dependency from upstream during build step. 
  Use go get golang.org/x/lint/golint instead of go get -u github.com/golang/lint/golint

* Tue Mar 05 2019 Lans Hung <lans.hung@oracle.com> - 4.0.0-1
- Initialize package.

